@@ -1,13 +1,13 @@
 #include "echoping.h"
 
-/* $Id: error.c,v 4.6 2003/11/05 12:29:15 bortz Exp $ */
+/* $Id: error.c 422 2009-01-13 20:52:51Z bortz $ */
 
 /* Most of error-handling routines stolen from Stevens' books */
 
 void
-my_perror ()
+my_perror()
 {
-  fprintf (stderr, " %s\n", sys_err_str ());
+    fprintf(stderr, " %s\n", sys_err_str());
 }
 
 /*
@@ -20,20 +20,20 @@ my_perror ()
 
 /* VARARGS1 */
 void
-err_ret (char *str, ...)
+err_ret(char *str, ...)
 {
-  va_list args;
+    va_list         args;
 
-  va_start (args, str);
-  vfprintf (stderr, str, args);
-  va_end (args);
+    va_start(args, str);
+    vfprintf(stderr, str, args);
+    va_end(args);
 
-  my_perror ();
+    my_perror();
 
-  fflush (stdout);
-  fflush (stderr);
+    fflush(stdout);
+    fflush(stderr);
 
-  return;
+    return;
 }
 
 /*
@@ -47,16 +47,16 @@ err_ret (char *str, ...)
 
 /* VARARGS1 */
 void
-err_quit (char *str, ...)
+err_quit(char *str, ...)
 {
-  va_list args;
+    va_list         args;
 
-  va_start (args, str);
-  vfprintf (stderr, str, args);
-  fputc ('\n', stderr);
-  va_end (args);
+    va_start(args, str);
+    vfprintf(stderr, str, args);
+    fputc('\n', stderr);
+    va_end(args);
 
-  exit (1);
+    exit(1);
 }
 
 /*
@@ -71,26 +71,25 @@ err_quit (char *str, ...)
 
 /* VARARGS1 */
 void
-err_sys (char *str, ...)
+err_sys(char *str, ...)
 {
-  va_list args;
+    va_list         args;
 
-  va_start (args, str);
-  vfprintf (stderr, str, args);
-  va_end (args);
+    va_start(args, str);
+    vfprintf(stderr, str, args);
+    va_end(args);
 
-  my_perror ();
+    my_perror();
 
-  exit (1);
+    exit(1);
 }
 
 void
-usage ()
+usage(poptContext context)
 {
-  fprintf (stderr,
-	   "Usage: %s [-4] [-6] [-v] [-r] [-f fill] [-t timeout] [-c] [-d] [-u] [-s size] [-n number] [-w delay] [-h url] [-i url] [-p priority] [-P tos] [-C] [-S] hostname[:port]\n",
-	   progname);
-  exit (1);
+    poptPrintUsage(context, stderr, 0);
+    fprintf(stderr, " hostname [plugin-options...]\n");
+    exit(1);
 }
 
 /*
@@ -103,18 +102,15 @@ usage ()
  * decimal value of errno to the other system. 
  */
 
-char *
-sys_err_str ()
+char           *
+sys_err_str()
 {
-  static char msgstr[200];
+    static char     msgstr[200];
 
-  if (errno != 0)
-    {
-      sprintf (msgstr, "(%s)", strerror(errno));
+    if (errno != 0) {
+        sprintf(msgstr, "(%s)", strerror(errno));
+    } else {
+        msgstr[0] = '\0';
     }
-  else
-    {
-      msgstr[0] = '\0';
-	}
-  return (msgstr);
+    return (msgstr);
 }
